@@ -53,7 +53,7 @@
 #if defined(LIBC_SCCS) && !defined(lint)
 /*static char *sccsid = "from: @(#)svc_tcp.c 1.21 87/08/11 Copyr 1984 Sun Micro";*/
 /*static char *sccsid = "from: @(#)svc_tcp.c	2.2 88/08/01 4.0 RPCSRC";*/
-static char *rcsid = "$Id: svc_tcp.c,v 1.5 2003/06/23 17:24:59 majka Exp $";
+static char *rcsid = "$Id: svc_tcp.c,v 1.6 2004/06/11 16:28:07 majka Exp $";
 #endif
 
 /*
@@ -348,11 +348,6 @@ readtcp(xprt, buf, len)
 		{
 			ready = TRUE;
 		}
-		else
-		{
-			svc_getreqset(&readfds);
-		}
-
 	} while (!ready);
 
 	if ((len = read(sock, buf, len)) > 0) return len;
